@@ -220,7 +220,7 @@ void CSettingDialog::initView()
             }
             if (wid->accessibleName().contains("DefaultWidgetAtContentRow")) {
                 //DefaultWidgetAtContentRow是设置对话框右边每一个option条目对应widget的accessibleName的前缀，所以如果后续有更多条目，需要做修改
-                wid->layout()->setMargin(0);
+                wid->layout()->setContentsMargins(0, 0, 0, 0);
             }
         }
     }
@@ -772,13 +772,7 @@ QWidget *CSettingDialog::createControlCenterLink(QObject *obj)
     myLabel->setFixedHeight(36);
     connect(myLabel, &DLabel::linkActivated, this, [this]{
         qCDebug(ClientLogger) << "open deepin control center";
-        QString datePage = ControlCenterPage;
-        auto ver = DSysInfo::majorVersion().toInt();
-        if (ver > 23) {
-            // v25 control center has changed the datetime page.
-            datePage = "system/timeAndLang";
-        }
-        this->m_controlCenterProxy->ShowPage(datePage);
+        this->m_controlCenterProxy->ShowPage(ControlCenterPage);
     });
     auto w = new QWidget(this);
     QHBoxLayout *layout = new QHBoxLayout(w);
